@@ -4,7 +4,7 @@ from __future__ import annotations
 
 import re
 from datetime import datetime
-from typing import Any, Dict, Optional
+from typing import Any, Dict, Optional, List
 from uuid import UUID
 
 from pydantic import BaseModel, Field, validator
@@ -15,31 +15,39 @@ from fleet.types import VerifierFunction
 
 class Task(BaseModel):
     """A task model representing a single task in the Fleet system."""
-    
+
     key: str = Field(..., description="Unique task key identifier")
     prompt: str = Field(..., description="Task prompt or instruction")
     env_id: str = Field(..., description="Environment identifier")
-    env_variables: Optional[Dict[str, Any]] = Field(default_factory=dict, description="Environment variables")
+    env_variables: Optional[Dict[str, Any]] = Field(
+        default_factory=dict, description="Environment variables"
+    )
     created_at: Optional[datetime] = Field(None, description="Task creation timestamp")
     version: Optional[str] = Field(None, description="Task version")
     verifier_func: Optional[str] = Field(None, description="Verifier function code")
-    verifier: Optional[Any] = Field(None, description="Verifier function with decorator (async or sync)")
+    verifier: Optional[Any] = Field(
+        None, description="Verifier function with decorator (async or sync)"
+    )
     verifier_id: Optional[str] = Field(None, description="Verifier identifier")
     verifier_sha: Optional[str] = Field(None, description="Verifier SHA256 hash")
-    metadata: Optional[Dict[str, Any]] = Field(default_factory=dict, description="Additional task metadata")
+    metadata: Optional[Dict[str, Any]] = Field(
+        default_factory=dict, description="Additional task metadata"
+    )
 
-    @validator('key')
+    @validator("key")
     def validate_key_format(cls, v):
         """Validate key follows kebab-case format."""
-        if not re.match(r'^[a-z0-9]+(-[a-z0-9]+)*$', v):
-            raise ValueError(f'Invalid task key format: {v}. Must follow kebab-case format.')
+        if not re.match(r"^[a-z0-9]+(-[a-z0-9]+)*$", v):
+            raise ValueError(
+                f"Invalid task key format: {v}. Must follow kebab-case format."
+            )
         return v
 
-    @validator('created_at', pre=True, always=True)
+    @validator("created_at", pre=True, always=True)
     def set_created_at(cls, v):
         """Set created_at to current time if not provided."""
         return v or datetime.now()
-    
+
     @property
     def env_key(self) -> str:
         """Get the environment key combining env_id and version."""
@@ -49,24 +57,25 @@ class Task(BaseModel):
 
     class Config:
         """Pydantic model configuration."""
+
         json_encoders = {
             datetime: lambda v: v.isoformat(),
         }
         # Allow arbitrary types for the verifier field
-        arbitrary_types_allowed = True 
+        arbitrary_types_allowed = True
 
     def verify(self, env, *args, **kwargs) -> float:
         """Verify the task using the verifier function (sync version).
-        
+
         For sync environments, calls the sync verifier directly.
         For async verifiers, automatically runs them with asyncio.run().
         """
         if self.verifier:
             import asyncio
             import inspect
-            
+
             result = self.verifier.remote(env, *args, **kwargs)
-            
+
             # If the result is a coroutine, we need to run it
             if inspect.iscoroutine(result):
                 # Check if we're already in an event loop
@@ -84,10 +93,10 @@ class Task(BaseModel):
                 return result
         else:
             raise ValueError("No verifier function found for this task")
-    
+
     async def verify_async(self, *args, **kwargs) -> float:
         """Verify the task using the verifier function (async version).
-        
+
         For async environments, awaits the async verifier.
         Works with both sync and async verifiers in async contexts.
         """
@@ -95,9 +104,53 @@ class Task(BaseModel):
             result = self.verifier.remote(*args, **kwargs)
             # If it's a coroutine, await it
             import inspect
+
             if inspect.iscoroutine(result):
                 return await result
             else:
                 return result
         else:
             raise ValueError("No verifier function found for this task")
+
+    async def make_env(self, region: Optional[str] = None):
+        """Create an environment instance for this task's environment.
+
+        Uses the task's env_id (and version if present) to create the env.
+        """
+        if not self.env_id:
+            raise ValueError("Task has no env_id defined")
+        # Deferred import to avoid circular dependencies
+        from .client import AsyncFleet
+
+        return await AsyncFleet().make(env_key=self.env_key, region=region)
+
+
+async def load_tasks(
+    env_key: Optional[str] = None,
+    keys: Optional[List[str]] = None,
+    version: Optional[str] = None,
+    team_id: Optional[str] = None
+) -> List[Task]:
+    """Convenience function to load tasks with optional filtering.
+
+    Args:
+        env_key: Optional environment key to filter tasks by
+        keys: Optional list of task keys to filter by
+        version: Optional version to filter tasks by
+        team_id: Optional team_id to filter by (admin only)
+
+    Examples:
+        tasks = await fleet.load_tasks(env_key="fira")
+        tasks = await fleet.load_tasks(keys=["task1", "task2"])
+        tasks = await fleet.load_tasks(env_key="fira", version="v1.0")
+    """
+    # Use the global client by default so users can pre-configure it once
+    from .global_client import get_client
+
+    client = get_client()
+    return await client.load_tasks(
+        env_key=env_key, 
+        keys=keys, 
+        version=version, 
+        team_id=team_id
+    )
